==> jc-1.4.0.tar.gz: java/lang/Error.h <==
// public class java.lang.Error

// class file dependencies
// @dep_class 308333d803f5ab9f java_lang_Error
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable

// header file dependencies
// @dep_header java_lang_Throwable

#include "java/lang/Throwable.h"

#ifndef _JC_java_lang_Error_H_
#define _JC_java_lang_Error_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_lang_Throwable$object;

// Typedefs
typedef struct _jc_java_lang_Error$sub_refs	_jc_java_lang_Error$sub_refs;
typedef struct _jc_java_lang_Error$sub_nonrefs	_jc_java_lang_Error$sub_nonrefs;
typedef struct _jc_java_lang_Error$refs	_jc_java_lang_Error$refs;
typedef struct _jc_java_lang_Error$nonrefs	_jc_java_lang_Error$nonrefs;
typedef struct _jc_java_lang_Error$object	_jc_java_lang_Error$object;

typedef struct _jc_java_lang_Error$fields_struct	_jc_java_lang_Error$fields_struct;
typedef const struct _jc_java_lang_Error$vmethods	_jc_java_lang_Error$vmethods;
typedef const struct _jc_java_lang_Error$vtable	_jc_java_lang_Error$vtable;
typedef const struct _jc_java_lang_Error$vtype	_jc_java_lang_Error$vtype;

// Class fields structure
struct _jc_java_lang_Error$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_lang_Error$fields_struct _jc_java_lang_Error$class_fields;

// Constructors
extern void _jc_java_lang_Error$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_lang_Error$object *);
extern void _jc_java_lang_Error$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_lang_Error$object *, struct _jc_java_lang_String$object *);
extern void _jc_java_lang_Error$method$_init$e87bb26efeed946b(_jc_env *, struct _jc_java_lang_Error$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_Throwable$object *);
extern void _jc_java_lang_Error$method$_init$8b52a141d2a0e2bc(_jc_env *, struct _jc_java_lang_Error$object *, struct _jc_java_lang_Throwable$object *);

// Virtual methods structure
struct _jc_java_lang_Error$vmethods {
};

// Vtable
struct _jc_java_lang_Error$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Error$vmethods	java_lang_Error;
};

// Vtype
struct _jc_java_lang_Error$vtype {
	_jc_type			type;
	_jc_java_lang_Error$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_lang_Error$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_lang_Error$refs {
    _jc_java_lang_Error$sub_refs	java_lang_Error;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_lang_Error$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_lang_Error$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Error$sub_nonrefs	java_lang_Error;
};

// Object instance structure
struct _jc_java_lang_Error$object {
	_jc_java_lang_Error$refs	refs[0];
	_jc_word		lockword;
	_jc_java_lang_Error$vtype	*vtype;
	_jc_java_lang_Error$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_lang_Error$vtype _jc_java_lang_Error$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_lang_Error, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_lang_Error$class_object;

#endif	/* _JC_java_lang_Error_H_ */

==> jc-1.4.6.tar.gz: java/lang/Error.h <==
// public class java.lang.Error

// class file dependencies
// @dep_class 308333d803f5ab9f java_lang_Error
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable

// header file dependencies
// @dep_header java_lang_Throwable

#include "java/lang/Throwable.h"

#ifndef _JC_java_lang_Error_H_
#define _JC_java_lang_Error_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_lang_Throwable$object;

// Typedefs
typedef struct _jc_java_lang_Error$sub_refs	_jc_java_lang_Error$sub_refs;
typedef struct _jc_java_lang_Error$sub_nonrefs	_jc_java_lang_Error$sub_nonrefs;
typedef struct _jc_java_lang_Error$refs	_jc_java_lang_Error$refs;
typedef struct _jc_java_lang_Error$nonrefs	_jc_java_lang_Error$nonrefs;
typedef struct _jc_java_lang_Error$object	_jc_java_lang_Error$object;

typedef struct _jc_java_lang_Error$fields_struct	_jc_java_lang_Error$fields_struct;
typedef const struct _jc_java_lang_Error$vmethods	_jc_java_lang_Error$vmethods;
typedef const struct _jc_java_lang_Error$vtable	_jc_java_lang_Error$vtable;
typedef const struct _jc_java_lang_Error$vtype	_jc_java_lang_Error$vtype;

// Class fields structure
struct _jc_java_lang_Error$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_lang_Error$fields_struct _jc_java_lang_Error$class_fields;

// Constructors
extern void _jc_java_lang_Error$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_lang_Error$object *) _JC_JCNI_ATTR;
extern void _jc_java_lang_Error$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_lang_Error$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern void _jc_java_lang_Error$method$_init$e87bb26efeed946b(_jc_env *, struct _jc_java_lang_Error$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_Throwable$object *) _JC_JCNI_ATTR;
extern void _jc_java_lang_Error$method$_init$8b52a141d2a0e2bc(_jc_env *, struct _jc_java_lang_Error$object *, struct _jc_java_lang_Throwable$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_lang_Error$vmethods {
};

// Vtable
struct _jc_java_lang_Error$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Error$vmethods	java_lang_Error;
};

// Vtype
struct _jc_java_lang_Error$vtype {
	_jc_type			type;
	_jc_java_lang_Error$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_lang_Error$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_lang_Error$refs {
    _jc_java_lang_Error$sub_refs	java_lang_Error;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_lang_Error$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_lang_Error$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Error$sub_nonrefs	java_lang_Error;
};

// Object instance structure
struct _jc_java_lang_Error$object {
	_jc_java_lang_Error$refs	refs[0];
	_jc_word		lockword;
	_jc_java_lang_Error$vtype	*vtype;
	_jc_java_lang_Error$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_lang_Error$vtype _jc_java_lang_Error$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_lang_Error, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_lang_Error$class_object;

#endif	/* _JC_java_lang_Error_H_ */
